pub trait Display {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
Format trait for an empty format, {}.
Implementing this trait for a type will automatically implement the
ToString trait for the type, allowing the usage
of the .to_string() method. Prefer implementing
the Display trait for a type, rather than ToString.
Display is similar to Debug, but Display is for user-facing
output, and so cannot be derived.
For more information on formatters, see the module-level documentation.
Completeness and parseability
Display for a type might not necessarily be a lossless or complete representation of the type.
It may omit internal state, precision, or other information the type does not consider important
for user-facing output, as determined by the type. As such, the output of Display might not be
possible to parse, and even if it is, the result of parsing might not exactly match the original
value.
However, if a type has a lossless Display implementation whose output is meant to be
conveniently machine-parseable and not just meant for human consumption, then the type may wish
to accept the same format in FromStr, and document that usage. Having both Display and
FromStr implementations where the result of Display cannot be parsed with FromStr may
surprise users.
Internationalization
Because a type can only have one Display implementation, it is often preferable
to only implement Display when there is a single most “obvious” way that
values can be formatted as text. This could mean formatting according to the
“invariant” culture and “undefined” locale, or it could mean that the type
display is designed for a specific culture/locale, such as developer logs.
If not all values have a justifiably canonical textual format or if you want
to support alternative formats not covered by the standard set of possible
formatting traits, the most flexible approach is display adapters: methods
like str::escape_default or Path::display which create a wrapper
implementing Display to output the specific display format.
Examples
Implementing Display on a type:
use std::fmt;
struct Point {
x: i32,
y: i32,
}
impl fmt::Display for Point {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.x, self.y)
}
}
let origin = Point { x: 0, y: 0 };
assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Examples
use std::fmt;
struct Position {
longitude: f32,
latitude: f32,
}
impl fmt::Display for Position {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "({}, {})", self.longitude, self.latitude)
}
}
assert_eq!(
"(1.987, 2.983)",
format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);Implementors
impl Display for Value
impl Display for AsciiChar
impl Display for Infallible
impl Display for FromBytesWithNulError
impl Display for IpAddr
impl Display for SocketAddr
impl Display for core::slice::GetDisjointMutError
impl Display for VarError
impl Display for std::fs::TryLockError
impl Display for std::sync::mpsc::RecvTimeoutError
impl Display for std::sync::mpsc::TryRecvError
impl Display for RoundingError
impl Display for chrono::weekday::Weekday
impl Display for crossbeam_channel::err::RecvTimeoutError
impl Display for crossbeam_channel::err::TryRecvError
impl Display for GetTimezoneError
impl Display for log::Level
impl Display for log::LevelFilter
impl Display for BernoulliError
impl Display for WeightedError
impl Display for regex_automata::dfa::automaton::StartError
impl Display for regex_automata::hybrid::error::StartError
impl Display for Ast
Print a display representation of this Ast.
This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.
This implementation uses constant stack space and heap space proportional
to the size of the Ast.
impl Display for regex_syntax::ast::ErrorKind
impl Display for regex_syntax::error::Error
impl Display for regex_syntax::hir::ErrorKind
impl Display for regex::error::Error
impl Display for slab::GetDisjointMutError
impl Display for CollectionAllocErr
impl Display for time::error::Error
impl Display for Format
impl Display for InvalidFormatDescription
impl Display for Parse
impl Display for ParseFromDescription
impl Display for TryFromParsed
impl Display for Month
impl Display for time::weekday::Weekday
impl Display for TryAcquireError
impl Display for tokio::sync::broadcast::error::RecvError
impl Display for tokio::sync::broadcast::error::TryRecvError
impl Display for BigEndian
impl Display for LittleEndian
impl Display for hydro2_3p::io::ErrorKind
impl Display for hydro2_3p::mpsc::error::TryRecvError
impl Display for hydro2_3p::oneshot::error::TryRecvError
impl Display for bool
impl Display for char
impl Display for f16
impl Display for f32
impl Display for f64
impl Display for i8
impl Display for i16
impl Display for i32
impl Display for i64
impl Display for i128
impl Display for isize
impl Display for !
impl Display for str
impl Display for u8
impl Display for u16
impl Display for u32
impl Display for u64
impl Display for u128
impl Display for usize
impl Display for ColoredString
impl Display for hydro2_3p::de::value::Error
impl Display for ByteString
impl Display for UnorderedKeyError
impl Display for TryReserveError
impl Display for FromVecWithNulError
impl Display for IntoStringError
impl Display for NulError
impl Display for FromUtf8Error
impl Display for FromUtf16Error
impl Display for String
impl Display for LayoutError
impl Display for AllocError
impl Display for TryFromSliceError
impl Display for core::ascii::EscapeDefault
impl Display for ByteStr
impl Display for BorrowError
impl Display for BorrowMutError
impl Display for CharTryFromError
impl Display for ParseCharError
impl Display for DecodeUtf16Error
impl Display for core::char::EscapeDebug
impl Display for core::char::EscapeDefault
impl Display for core::char::EscapeUnicode
impl Display for ToLowercase
impl Display for ToUppercase
impl Display for TryFromCharError
impl Display for FromBytesUntilNulError
impl Display for Arguments<'_>
impl Display for core::fmt::Error
impl Display for Ipv4Addr
impl Display for Ipv6Addr
Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.
impl Display for AddrParseError
impl Display for SocketAddrV4
impl Display for SocketAddrV6
impl Display for core::num::dec2flt::ParseFloatError
impl Display for core::num::error::ParseIntError
impl Display for core::num::error::TryFromIntError
impl Display for Location<'_>
impl Display for PanicInfo<'_>
impl Display for PanicMessage<'_>
impl Display for ParseBoolError
impl Display for Utf8Error
impl Display for TryFromFloatSecsError
impl Display for Backtrace
impl Display for JoinPathsError
impl Display for std::ffi::os_str::Display<'_>
impl Display for WriterPanicked
impl Display for PanicHookInfo<'_>
impl Display for std::path::Display<'_>
impl Display for NormalizeError
impl Display for StripPrefixError
impl Display for ExitStatus
impl Display for ExitStatusError
impl Display for std::sync::mpsc::RecvError
impl Display for WouldBlock
impl Display for SystemTimeError
impl Display for aho_corasick::util::error::BuildError
impl Display for aho_corasick::util::error::MatchError
impl Display for aho_corasick::util::primitives::PatternIDError
impl Display for aho_corasick::util::primitives::StateIDError
impl Display for StrippedStr<'_>
impl Display for Reset
impl Display for Style
impl Display for TryGetError
impl Display for chrono::format::ParseError
impl Display for ParseMonthError
impl Display for NaiveDate
The Display output of the naive date d is the same as
d.format("%Y-%m-%d").
The string printed can be readily parsed via the parse method on str.
Example
use chrono::NaiveDate;
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");impl Display for NaiveDateTime
The Display output of the naive date and time dt is the same as
dt.format("%Y-%m-%d %H:%M:%S%.f").
It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)
Example
use chrono::NaiveDate;
let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");Leap seconds may also be used.
let dt =
NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");impl Display for NaiveTime
The Display output of the naive time t is the same as
t.format("%H:%M:%S%.f").
The string printed can be readily parsed via the parse method on str.
It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)
Example
use chrono::NaiveTime;
assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
"23:56:04.012"
);
assert_eq!(
format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
"23:56:04.001234"
);
assert_eq!(
format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
"23:56:04.000123456"
);Leap seconds may also be used.
assert_eq!(
format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
"06:59:60.500"
);impl Display for FixedOffset
impl Display for Utc
impl Display for OutOfRange
impl Display for OutOfRangeError
impl Display for TimeDelta
impl Display for ParseWeekdayError
impl Display for WeekdaySet
Print the collection as a slice-like list of weekdays.
Example
use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());impl Display for crossbeam_channel::err::RecvError
impl Display for SelectTimeoutError
impl Display for TrySelectError
impl Display for deranged::ParseIntError
impl Display for deranged::TryFromIntError
impl Display for UninitializedFieldError
impl Display for env_filter::parser::ParseError
impl Display for env_logger::fmt::humantime::Timestamp
impl Display for futures_channel::mpsc::SendError
impl Display for futures_channel::mpsc::TryRecvError
impl Display for Canceled
impl Display for EnterError
impl Display for SpawnError
impl Display for Aborted
impl Display for getrandom::error::Error
impl Display for jiff::civil::date::Date
impl Display for jiff::civil::datetime::DateTime
Converts a DateTime into an ISO 8601 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::civil::date;
// No fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 0);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00");
// With fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00.123");
Example: setting the precision
use jiff::civil::date;
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt:.6}"), "2024-06-15T07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{dt:.300}"), "2024-06-15T07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{dt:.0}"), "2024-06-15T07:00:00");
impl Display for jiff::civil::time::Time
Converts a Time into an ISO 8601 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
use jiff::civil::time;
// No fractional seconds:
let t = time(7, 0, 0, 0);
assert_eq!(format!("{t}"), "07:00:00");
// With fractional seconds:
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t}"), "07:00:00.123");
Example: setting the precision
use jiff::civil::time;
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t:.6}"), "07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{t:.300}"), "07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{t:.0}"), "07:00:00");
impl Display for jiff::error::Error
impl Display for SignedDuration
impl Display for Span
impl Display for jiff::timestamp::Timestamp
Converts a Timestamp datetime into a RFC 3339 compliant string.
Since a Timestamp never has an offset associated with it and is always
in UTC, the string emitted by this trait implementation uses Z for “Zulu”
time. The significance of Zulu time is prescribed by RFC 9557 and means
that “the time in UTC is known, but the offset to local time is unknown.”
If you need to emit an RFC 3339 compliant string with a specific offset,
then use Timestamp::display_with_offset.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::Timestamp;
// No fractional seconds.
let ts = Timestamp::from_second(1_123_456_789)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49Z");
// With fractional seconds.
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49.123Z");
Example: setting the precision
use jiff::Timestamp;
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(
format!("{ts:.6}"),
"2005-08-07T23:19:49.123000Z",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
format!("{ts:.300}"),
"2005-08-07T23:19:49.123000000Z",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
format!("{ts:.0}"),
"2005-08-07T23:19:49Z",
);
impl Display for TimestampDisplayWithOffset
impl Display for Offset
impl Display for Zoned
Converts a Zoned datetime into a RFC 9557 compliant string.
Formatting options supported
std::fmt::Formatter::precisioncan be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.
Example
This shows the default rendering:
use jiff::civil::date;
// No fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 0).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00-04:00[US/Eastern]");
// With fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00.123-04:00[US/Eastern]");
Example: setting the precision
use jiff::civil::date;
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(
format!("{zdt:.6}"),
"2024-06-15T07:00:00.123000-04:00[US/Eastern]",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
format!("{zdt:.300}"),
"2024-06-15T07:00:00.123000000-04:00[US/Eastern]",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
format!("{zdt:.0}"),
"2024-06-15T07:00:00-04:00[US/Eastern]",
);
impl Display for log::ParseLevelError
impl Display for SetLoggerError
impl Display for num_traits::ParseFloatError
impl Display for ReadError
impl Display for rand_core::error::Error
impl Display for regex_automata::dfa::dense::BuildError
impl Display for regex_automata::dfa::onepass::BuildError
impl Display for regex_automata::hybrid::error::BuildError
impl Display for CacheError
impl Display for regex_automata::meta::error::BuildError
impl Display for regex_automata::nfa::thompson::error::BuildError
impl Display for GroupInfoError
impl Display for UnicodeWordBoundaryError
impl Display for regex_automata::util::primitives::PatternIDError
impl Display for SmallIndexError
impl Display for regex_automata::util::primitives::StateIDError
impl Display for regex_automata::util::search::MatchError
impl Display for PatternSetInsertError
impl Display for DeserializeError
impl Display for SerializeError
impl Display for regex_syntax::ast::Error
impl Display for regex_syntax::hir::Error
impl Display for Hir
Print a display representation of this Hir.
The result of this is a valid regular expression pattern string.
This implementation uses constant stack space and heap space proportional
to the size of the Hir.
impl Display for CaseFoldError
impl Display for UnicodeWordError
impl Display for regex::regex::bytes::Regex
impl Display for regex::regex::string::Regex
impl Display for serde_json::error::Error
impl Display for Number
impl Display for time::date::Date
impl Display for Duration
The format returned by this implementation is not stable and must not be relied upon.
By default this produces an exact, full-precision printout of the duration.
For a concise, rounded printout instead, you can use the .N format specifier:
let duration = Duration::new(123456, 789011223);
println!("{duration:.3}");For the purposes of this implementation, a day is exactly 24 hours and a minute is exactly 60 seconds.
impl Display for ComponentRange
impl Display for ConversionRange
impl Display for DifferentVariant
impl Display for InvalidVariant
impl Display for OffsetDateTime
impl Display for PrimitiveDateTime
impl Display for time::time::Time
impl Display for UtcDateTime
impl Display for UtcOffset
impl Display for tokio::net::tcp::split_owned::ReuniteError
impl Display for tokio::net::unix::split_owned::ReuniteError
impl Display for TryCurrentError
impl Display for JoinError
impl Display for Id
impl Display for AcquireError
impl Display for tokio::sync::mutex::TryLockError
impl Display for tokio::sync::watch::error::RecvError
impl Display for Elapsed
impl Display for tokio::time::error::Error
impl Display for InitError
impl Display for SetGlobalDefaultError
impl Display for Field
impl Display for FieldSet
impl Display for ValueSet<'_>
impl Display for tracing_core::metadata::Level
impl Display for tracing_core::metadata::LevelFilter
impl Display for tracing_core::metadata::ParseLevelError
impl Display for ParseLevelFilterError
impl Display for tracing_subscriber::filter::directive::ParseError
impl Display for Directive
impl Display for BadName
impl Display for EnvFilter
impl Display for FromEnvError
impl Display for Targets
impl Display for tracing_subscriber::reload::Error
impl Display for TryInitError
impl Display for hydro2_3p::io::Error
impl Display for hydro2_3p::oneshot::error::RecvError
impl Display for AccessError
impl Display for dyn Expected + '_
impl Display for dyn Value
impl<'a> Display for Unexpected<'a>
impl<'a> Display for EscapeAscii<'a>
impl<'a> Display for core::str::iter::EscapeDebug<'a>
impl<'a> Display for core::str::iter::EscapeDefault<'a>
impl<'a> Display for core::str::iter::EscapeUnicode<'a>
impl<'a, I, B> Display for DelayedFormat<I>
impl<'a, K, V> Display for std::collections::hash::map::OccupiedError<'a, K, V>
impl<'a, K, V, A> Display for alloc::collections::btree::map::entry::OccupiedError<'a, K, V, A>
impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
impl<'a, T> Display for hydro2_3p::AsyncRwLockReadGuard<'a, T>
impl<'a, T> Display for hydro2_3p::AsyncRwLockWriteGuard<'a, T>
impl<'d> Display for TimeZoneName<'d>
impl<'f> Display for jiff::fmt::strtime::Display<'f>
impl<'n> Display for Pieces<'n>
impl<A, S, V> Display for ConvertError<A, S, V>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<B> Display for Cow<'_, B>
impl<E> Display for Report<E>where
E: Error,
impl<E> Display for FormattedFields<E>where
E: ?Sized,
impl<F> Display for FromFn<F>
impl<O> Display for F32<O>where
O: ByteOrder,
impl<O> Display for F64<O>where
O: ByteOrder,
impl<O> Display for I16<O>where
O: ByteOrder,
impl<O> Display for I32<O>where
O: ByteOrder,
impl<O> Display for I64<O>where
O: ByteOrder,
impl<O> Display for I128<O>where
O: ByteOrder,
impl<O> Display for Isize<O>where
O: ByteOrder,
impl<O> Display for U16<O>where
O: ByteOrder,
impl<O> Display for U32<O>where
O: ByteOrder,
impl<O> Display for U64<O>where
O: ByteOrder,
impl<O> Display for U128<O>where
O: ByteOrder,
impl<O> Display for Usize<O>where
O: ByteOrder,
impl<Ptr> Display for Pin<Ptr>where
Ptr: Display,
impl<Src, Dst> Display for AlignmentError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for SizeError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.
impl<Src, Dst> Display for ValidityError<Src, Dst>
Produces a human-readable error message.
The message differs between debug and release builds. When
debug_assertions are enabled, this message is verbose and includes
potentially sensitive information.